@@ -2,7 +2,7 @@
 #'
 #' This function performs one-sample, two-sample, and paired-sample z-tests and
 #' provides descriptive statistics, effect size measure, and a plot showing error
-#' bars for confidence intervals with jittered data points.
+#' bars for (difference-adjusted) confidence intervals with jittered data points.
 #'
 #' Cohen's d reported when argument \code{effsize = TRUE} is based on the population
 #' standard deviation specified in \code{sigma} or the square root of the population
@@ -15,93 +15,95 @@
 #' pooled population standard deviation when assuming and specifying unequal standard
 #' deviations.
 #'
-#' @param x            a numeric vector of data values.
-#' @param y            a numeric vector of data values.
-#' @param sigma        a numeric vector indicating the population standard deviation(s).
-#'                     In case of two-sample z-test, equal standard deviations are
-#'                     assumed when specifying one value for the argument \code{sigma};
-#'                     when specifying two values for the argument \code{sigma},
-#'                     unequal standard deviations are assumed. Note that either
-#'                     argument \code{sigma} or argument \code{sigma2} is specified.
-#' @param sigma2       a numeric vector indicating the population variance(s). In
-#'                     case of two-sample z-test, equal variances are assumed when
-#'                     specifying one value for the argument \code{sigma2}; when
-#'                     specifying two values for the argument \code{sigma}, unequal
-#'                     variance are assumed. Note that either argument \code{sigma}
-#'                     or argument \code{sigma2} is specified.
-#' @param mu           a numeric value indicating the population mean under the null
-#'                     hypothesis. Note that the argument \code{mu} is only used
-#'                     when computing a one-sample z-test.
-#' @param paired       logical: if \code{TRUE}, paired-sample z-test is computed.
-#' @param alternative  a character string specifying the alternative hypothesis,
-#'                     must be one of \code{"two.sided"} (default), \code{"greater"}
-#'                     or \code{"less"}.
-#' @param hypo         logical: if \code{TRUE}, null and alternative hypothesis are
-#'                     shown on the console.
-#' @param descript     logical: if \code{TRUE}, descriptive statistics are shown
-#'                     on the console.
-#' @param effsize      logical: if \code{TRUE}, effect size measure Cohen's d is
-#'                     shown on the console.
-#' @param conf.level   a numeric value between 0 and 1 indicating the confidence
-#'                     level of the interval.
-#' @param plot         logical: if \code{TRUE}, a plot showing error bars for
-#'                     confidence intervals is drawn.
-#' @param point.size   a numeric value indicating the \code{size} aesthetic for
-#'                     the point representing the mean value.
-#' @param error.width  a numeric value indicating the horizontal bar width of
-#'                     the error bar.
-#' @param xlab         a character string specifying the labels for the x-axis.
-#' @param ylab         a character string specifying the labels for the y-axis.
-#' @param ylim         a numeric vector of length two specifying limits of the
-#'                     limits of the y-axis.
-#' @param breaks       a numeric vector specifying the points at which tick-marks
-#'                     are drawn at the y-axis.
-#' @param line         logical: if \code{TRUE} (default), a horizontal line
-#'                     is drawn at \code{mu} for the one-sample t-test or at
-#'                     0 for the paired-sample t-test.
-#' @param line.type    an integer value or character string specifying the line
-#'                     type for the line representing the population mean under
-#'                     the null hypothesis, i.e., 0 = blank, 1 = solid, 2 = dashed,
-#'                     3 = dotted, 4 = dotdash, 5 = longdash, 6 = twodash.
-#' @param line.size    a numeric value indicating the \code{size} aesthetic
-#'                     for the line representing the population mean under the
-#'                     null hypothesis.
-#' @param jitter       logical: if \code{TRUE} (default), jittered data points
-#'                     are drawn.
-#' @param jitter.size  a numeric value indicating the \code{size} aesthetic
-#'                     for the jittered data points.
-#' @param jitter.width a numeric value indicating the amount of vertical and
-#'                     horizontal jitter.
-#' @param jitter.alpha a numeric value indicating the opacity of the jittered
-#'                     data points.
-#' @param title        a character string specifying the text for the title for
-#'                     the plot.
-#' @param subtile      a character string specifying the text for the subtitle for
-#'                     the plot.
-#' @param digits       an integer value indicating the number of decimal places to
-#'                     be used for displaying descriptive statistics and confidence
-#'                     interval.
-#' @param p.digits     an integer value indicating the number of decimal places to
-#'                     be used for displaying the \emph{p}-value.
-#' @param as.na        a numeric vector indicating user-defined missing values,
-#'                     i.e. these values are converted to \code{NA} before conducting
-#'                     the analysis.
-#' @param check        logical: if \code{TRUE}, argument specification is checked.
-#' @param output       logical: if \code{TRUE}, output is shown on the console.
-#' @param formula      in case of two sample z-test (i.e., \code{paired = FALSE}),
-#'                     a formula of the form \code{y ~ group} where \code{group}
-#'                     is a numeric variable, character variable
-#'                     or factor with two values or factor levels giving the
-#'                     corresponding groups.
-#' @param data         a matrix or data frame containing the variables in the formula
-#'                     \code{formula}.
-#' @param ...          further arguments to be passed to or from methods.
+#' @param x             a numeric vector of data values.
+#' @param y             a numeric vector of data values.
+#' @param sigma         a numeric vector indicating the population standard deviation(s).
+#'                      In case of two-sample z-test, equal standard deviations are
+#'                      assumed when specifying one value for the argument \code{sigma};
+#'                      when specifying two values for the argument \code{sigma},
+#'                      unequal standard deviations are assumed. Note that either
+#'                      argument \code{sigma} or argument \code{sigma2} is specified.
+#' @param sigma2        a numeric vector indicating the population variance(s). In
+#'                      case of two-sample z-test, equal variances are assumed when
+#'                      specifying one value for the argument \code{sigma2}; when
+#'                      specifying two values for the argument \code{sigma}, unequal
+#'                      variance are assumed. Note that either argument \code{sigma}
+#'                      or argument \code{sigma2} is specified.
+#' @param mu            a numeric value indicating the population mean under the null
+#'                      hypothesis. Note that the argument \code{mu} is only used
+#'                      when computing a one-sample z-test.
+#' @param paired        logical: if \code{TRUE}, paired-sample z-test is computed.
+#' @param alternative   a character string specifying the alternative hypothesis,
+#'                      must be one of \code{"two.sided"} (default), \code{"greater"}
+#'                      or \code{"less"}.
+#' @param hypo          logical: if \code{TRUE}, null and alternative hypothesis are
+#'                      shown on the console.
+#' @param descript      logical: if \code{TRUE}, descriptive statistics are shown
+#'                      on the console.
+#' @param effsize       logical: if \code{TRUE}, effect size measure Cohen's d is
+#'                      shown on the console.
+#' @param conf.level    a numeric value between 0 and 1 indicating the confidence
+#'                      level of the interval.
+#' @param plot          logical: if \code{TRUE}, a plot showing error bars for
+#'                      confidence intervals is drawn.
+#' @param point.size    a numeric value indicating the \code{size} aesthetic for
+#'                      the point representing the mean value.
+#' @param adjust        logical: if \code{TRUE} (default), difference-adjustment
+#'                      for the confidence intervals a two-sample design is applied.
+#' @param error.width   a numeric value indicating the horizontal bar width of
+#'                      the error bar.
+#' @param xlab          a character string specifying the labels for the x-axis.
+#' @param ylab          a character string specifying the labels for the y-axis.
+#' @param ylim          a numeric vector of length two specifying limits of the
+#'                      limits of the y-axis.
+#' @param breaks        a numeric vector specifying the points at which tick-marks
+#'                      are drawn at the y-axis.
+#' @param line          logical: if \code{TRUE} (default), a horizontal line
+#'                      is drawn at \code{mu} for the one-sample t-test or at
+#'                      0 for the paired-sample t-test.
+#' @param line.type     an integer value or character string specifying the line
+#'                      type for the line representing the population mean under
+#'                      the null hypothesis, i.e., 0 = blank, 1 = solid, 2 = dashed,
+#'                      3 = dotted, 4 = dotdash, 5 = longdash, 6 = twodash.
+#' @param line.size     a numeric value indicating the \code{size} aesthetic
+#'                      for the line representing the population mean under the
+#'                      null hypothesis.
+#' @param jitter        logical: if \code{TRUE} (default), jittered data points
+#'                      are drawn.
+#' @param jitter.size   a numeric value indicating the \code{size} aesthetic
+#'                      for the jittered data points.
+#' @param jitter.width  a numeric value indicating the amount of horizontal jitter.
+#' @param jitter.height a numeric value indicating the amount of vertical jitter.
+#' @param jitter.alpha  a numeric value indicating the opacity of the jittered
+#'                      data points.
+#' @param title         a character string specifying the text for the title for
+#'                      the plot.
+#' @param subtitle      a character string specifying the text for the subtitle for
+#'                      the plot.
+#' @param digits        an integer value indicating the number of decimal places to
+#'                      be used for displaying descriptive statistics and confidence
+#'                      interval.
+#' @param p.digits      an integer value indicating the number of decimal places to
+#'                      be used for displaying the \emph{p}-value.
+#' @param as.na         a numeric vector indicating user-defined missing values,
+#'                      i.e. these values are converted to \code{NA} before conducting
+#'                      the analysis.
+#' @param check         logical: if \code{TRUE}, argument specification is checked.
+#' @param output        logical: if \code{TRUE}, output is shown on the console.
+#' @param formula       in case of two sample z-test (i.e., \code{paired = FALSE}),
+#'                      a formula of the form \code{y ~ group} where \code{group}
+#'                      is a numeric variable, character variable
+#'                      or factor with two values or factor levels giving the
+#'                      corresponding groups.
+#' @param data          a matrix or data frame containing the variables in the formula
+#'                      \code{formula}.
+#' @param ...           further arguments to be passed to or from methods.
 #'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
 #'
 #' @seealso
-#' \code{\link{test.t}}, \code{\link{aov.b}}, \code{\link{test.welch}},
+#' \code{\link{test.t}}, \code{\link{aov.b}}, \code{\link{aov.w}}, \code{\link{test.welch}},
 #' \code{\link{cohens.d}}, \code{\link{ci.mean.diff}}, \code{\link{ci.mean}}
 #'
 #' @references
@@ -355,11 +357,12 @@ test.z <- function(x, ...) {
 test.z.default <- function(x, y = NULL, sigma = NULL, sigma2 = NULL, mu = 0,
                            paired = FALSE, alternative = c("two.sided", "less", "greater"),
                            conf.level = 0.95, hypo = TRUE, descript = TRUE, effsize = FALSE,
-                           plot = FALSE, point.size = 4, error.width = 0.1,
+                           plot = FALSE, point.size = 4, adjust = TRUE, error.width = 0.1,
                            xlab = NULL, ylab = NULL, ylim = NULL, breaks = ggplot2::waiver(),
                            line = TRUE, line.type = 3, line.size = 0.8, jitter = TRUE,
-                           jitter.size = 1.25, jitter.width = 0.05, jitter.alpha = 0.1,
-                           title = "",  subtitle = "Confidence Interval",
+                           jitter.size = 1.25, jitter.width = 0.05,
+                           jitter.height = 0, jitter.alpha = 0.1,
+                           title = "", subtitle = "Confidence Interval",
                            digits = 2, p.digits = 4, as.na = NULL, check = TRUE,
                            output = TRUE, ...) {
 
@@ -549,6 +552,10 @@ test.z.default <- function(x, y = NULL, sigma = NULL, sigma2 = NULL, mu = 0,
     # Check input 'plot'
     if (isTRUE(!is.logical(plot))) { stop("Please specify TRUE or FALSE for the argument 'plot'.", call. = FALSE) }
 
+    #......
+    # Check input 'adjust'
+    if (isTRUE(!is.logical(adjust))) { stop("Please specify TRUE or FALSE for the argument 'adjust'.", call. = FALSE) }
+
     #......
     # Check input 'line'
     if (isTRUE(!is.logical(line))) { stop("Please specify TRUE or FALSE for the argument 'line'.", call. = FALSE) }
@@ -710,7 +717,7 @@ test.z.default <- function(x, y = NULL, sigma = NULL, sigma2 = NULL, mu = 0,
 
            ###
            # Add jittered points
-           if (isTRUE(jitter)) { p <- p + ggplot2::geom_jitter(alpha = jitter.alpha, width = jitter.width, size = jitter.size) }
+           if (isTRUE(jitter)) { p <- p + ggplot2::geom_jitter(alpha = jitter.alpha, width = jitter.width, height = jitter.height, size = jitter.size) }
 
            p <- p + ggplot2::geom_point(data = result, ggplot2::aes(x = 0L, m), size = point.size) +
                   ggplot2::geom_errorbar(data = result, ggplot2::aes(x = 0L, y = m, ymin = m.low, ymax = m.upp), width = error.width) +
@@ -738,8 +745,8 @@ test.z.default <- function(x, y = NULL, sigma = NULL, sigma2 = NULL, mu = 0,
 
              # Confidence interval
              plot.ci <- data.frame(group = c(1, 2),
-                                   rbind(misty::ci.mean(x, sigma = sigma[1L], conf.level = conf.level, output = FALSE)$result,
-                                         misty::ci.mean(y, sigma = sigma[2L], conf.level = conf.level, output = FALSE)$result))
+                                   rbind(misty::ci.mean(x, sigma = sigma[1L], adjust = adjust, conf.level = conf.level, output = FALSE)$result,
+                                         misty::ci.mean(y, sigma = sigma[2L], adjust = adjust, conf.level = conf.level, output = FALSE)$result))
 
              ###
              # Crease ggplot
@@ -814,9 +821,8 @@ test.z.default <- function(x, y = NULL, sigma = NULL, sigma2 = NULL, mu = 0,
                              xlab = xlab, ylab = ylab, ylim = ylim, breaks = breaks,
                              line = line, line.type = line.type, line.size = line.size,
                              jitter = jitter, jitter.size = jitter.size, jitter.width = jitter.width,
-                             jitter.alpha = jitter.alpha,
-                             title = title, subtitle = subtitle,
-                             digits = digits, p.digits = p.digits,
+                             jitter.height = jitter.height, jitter.alpha = jitter.alpha,
+                             title = title, subtitle = subtitle, digits = digits, p.digits = p.digits,
                              as.na = as.na, check = check, output = output),
                  result = result)
 
@@ -838,12 +844,12 @@ test.z.default <- function(x, y = NULL, sigma = NULL, sigma2 = NULL, mu = 0,
 test.z.formula <- function(formula, data, sigma = NULL, sigma2 = NULL,
                            alternative = c("two.sided", "less", "greater"),
                            conf.level = 0.95, hypo = TRUE, descript = TRUE, effsize = FALSE,
-                           plot = FALSE, point.size = 4, error.width = 0.1,
+                           plot = FALSE, point.size = 4, adjust = TRUE, error.width = 0.1,
                            xlab = NULL, ylab = NULL, ylim = NULL, breaks = ggplot2::waiver(),
-                           jitter = TRUE, jitter.size = 1.25,  jitter.width = 0.05, jitter.alpha = 0.1,
-                           title = "",  subtitle = "Confidence Interval",
-                           digits = 2, p.digits = 4, as.na = NULL, check = TRUE,
-                           output = TRUE, ...) {
+                           jitter = TRUE, jitter.size = 1.25, jitter.width = 0.05,
+                           jitter.height = 0, jitter.alpha = 0.1, title = "",
+                           subtitle = "Confidence Interval", digits = 2, p.digits = 4,
+                           as.na = NULL, check = TRUE, output = TRUE, ...) {
 
   #......
   # Check if input 'formula' is missing
@@ -901,7 +907,7 @@ test.z.formula <- function(formula, data, sigma = NULL, sigma2 = NULL,
   # Arguments
 
   # Global variables
-  group <- m <- low <- upp <- NULL
+  group <- m <- low <- upp <- adjust <-  NULL
 
   #----------------------------------------
   # Alternative hypothesis
@@ -914,15 +920,14 @@ test.z.formula <- function(formula, data, sigma = NULL, sigma2 = NULL,
 
   object <- test.z.default(x = data.split[[1L]], y = data.split[[2L]],
                            sigma = sigma, sigma2 = sigma2, alternative = alternative,
-                           conf.level = conf.level,  hypo = hypo, descript = descript,
-                           effsize = effsize, plot = FALSE,
-                           point.size = point.size, error.width = error.width,
-                           xlab = xlab, ylab = ylab, ylim = ylim, breaks = breaks,
-                           jitter = jitter, jitter.size = jitter.size, jitter.width = jitter.width,
-                           jitter.alpha = jitter.alpha,
-                           title = title, subtitle = subtitle,
-                           digits = digits, p.digits = p.digits, as.na = as.na,
-                           check = check, output = FALSE)
+                           conf.level = conf.level, hypo = hypo, descript = descript,
+                           effsize = effsize, plot = FALSE, point.size = point.size,
+                           error.width = error.width, xlab = xlab, ylab = ylab,
+                           ylim = ylim, breaks = breaks, jitter = jitter,
+                           jitter.size = jitter.size, jitter.width = jitter.width,
+                           jitter.height = jitter.height, jitter.alpha = jitter.alpha,
+                           title = title, subtitle = subtitle, digits = digits, p.digits = p.digits,
+                           as.na = as.na, check = check, output = FALSE)
 
   object$result[, "group"] <- names(data.split)
 
@@ -944,17 +949,17 @@ test.z.formula <- function(formula, data, sigma = NULL, sigma2 = NULL,
                  type = "test.z",
                  sample = "two",
                  data = data[, var.formula],
+                 formula = object$args$formula,
                  plot = p,
-                 args = list(formula = object$args$formula,
-                             sigma = object$args$sigma, sigma2 = object$args$sigma2,
+                 args = list(sigma = object$args$sigma, sigma2 = object$args$sigma2,
                              alternative = alternative, conf.level = conf.level,
                              hypo = hypo, descript = descript, effsize = effsize,
                              plot = plot, point.size = point.size, error.width = error.width,
                              xlab = xlab, ylab = ylab, ylim = ylim, breaks = breaks,
-                             jitter = jitter, jitter.size = jitter.size, jitter.alpha = jitter.alpha,
-                             jitter.width = jitter.width, title = title, subtitle = subtitle,
-                             digits = digits, p.digits = p.digits, as.na = as.na,
-                             check = check, output = object$args$output),
+                             jitter = jitter, jitter.size = jitter.size, jitter.width = jitter.width,
+                             jitter.height = jitter.height, jitter.alpha = jitter.alpha,
+                             title = title, subtitle = subtitle, digits = digits, p.digits = p.digits,
+                             as.na = as.na, check = check, output = object$args$output),
                  result = object$result)
 
   class(object) <- "misty.object"
